@@ -98,7 +98,7 @@ def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
     da.daily_avg(station, medfilter, ReqTracks, txtfile, pltit,
               extension, year1, year2, fr, csv) 
 
-    avgf = myxdir + '/Files/' + txtfile
+    avgf = myxdir + '/Files/' + station + '/' + txtfile
     x = np.loadtxt(avgf, comments='%')
     # delete the file!
     rh = x[:,2]
@@ -108,7 +108,7 @@ def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
     ii = (rh -medianvalue) < -0.05
     newx = x[ii,:] ; N=len(newx)
     if (N > 0):
-        snowfile = myxdir + '/Files/snowmask_' + station + '.txt' 
+        snowfile = myxdir + '/Files/' + station + 'snowmask_' + station + '.txt' 
         print('Suspect snow values stored in : ', snowfile)
         snow = open(snowfile, 'w+')
         for i in range(0,N):
@@ -191,13 +191,19 @@ def read_apriori_rh(station,fr):
     Returns
     -------
     results : numpy array 
-        column 1 is ?
+        column 1 is just a number (1,2,3,4, etc)
+
         column 2 is RH in meters
-        column 3 is sat 
-        column 4 is azimuth etc
+
+        column 3 is satellite number 
+
+        column 4 is azimuth of the track (degrees)
+
         column 5 is number of values used in average
-        column 6 is minimum azimuth degrees
-        column 7 is maximum azimuth degrees
+
+        column 6 is minimum azimuth degrees for the quadrant
+
+        column 7 is maximum azimuth degrees for the quadrant
     """
     result = []
     # do not have time to use this
